#[repr(u8)]pub enum Rwuid {
IDLE_NOTSET = 0,
IDLE_SET = 1,
}Variants
IDLE_NOTSET = 0
During receive standby state (RWU = 1), the IDLE bit does not get set upon detection of an idle character. During address match wakeup, the IDLE bit does not set when an address does not match.
IDLE_SET = 1
During receive standby state (RWU = 1), the IDLE bit gets set upon detection of an idle character. During address match wakeup, the IDLE bit does set when an address does not match.
Implementations